==> haskell-markdown-unlit-0.5.1-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-markdown-unlit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 markdown-unlit
version:              0.5.1
visibility:           public
id:                   markdown-unlit-0.5.1-CvbGnGEmL3y3b5cExR76HL
key:                  markdown-unlit-0.5.1-CvbGnGEmL3y3b5cExR76HL
license:              MIT
copyright:            (c) 2012-2020 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/markdown-unlit#readme
synopsis:             Literate Haskell support for Markdown
description:
    Documentation is here: <https://github.com/sol/markdown-unlit#readme>

category:             Development
abi:                  4938e4430232175ca683a4e952ff3cc2
exposed:              True
exposed-modules:      Text.Markdown.Unlit
hidden-modules:       Paths_markdown_unlit
import-dirs:          /usr/lib/ghc-8.10.3/site-local/markdown-unlit-0.5.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/markdown-unlit-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/markdown-unlit-0.5.1
hs-libraries:         HSmarkdown-unlit-0.5.1-CvbGnGEmL3y3b5cExR76HL
depends:
    base-4.14.1.0 base-compat-0.11.2-JggHr2fdYLe83DSFk1MYK3

haddock-interfaces:
    /usr/share/doc/haskell-markdown-unlit/html/markdown-unlit.haddock

haddock-html:         /usr/share/doc/haskell-markdown-unlit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-markdown-unlit-0.5.1-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-markdown-unlit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 markdown-unlit
version:              0.5.1
visibility:           public
id:                   markdown-unlit-0.5.1-FyVMUWdahY47InALmpaTjR
key:                  markdown-unlit-0.5.1-FyVMUWdahY47InALmpaTjR
license:              MIT
copyright:            (c) 2012-2020 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/markdown-unlit#readme
synopsis:             Literate Haskell support for Markdown
description:
    Documentation is here: <https://github.com/sol/markdown-unlit#readme>

category:             Development
abi:                  04a230353972b90682b2ad3db263133c
exposed:              True
exposed-modules:      Text.Markdown.Unlit
hidden-modules:       Paths_markdown_unlit
import-dirs:          /usr/lib/ghc-8.10.3/site-local/markdown-unlit-0.5.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/markdown-unlit-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/markdown-unlit-0.5.1
hs-libraries:         HSmarkdown-unlit-0.5.1-FyVMUWdahY47InALmpaTjR
depends:
    base-4.14.1.0 base-compat-0.11.2-JggHr2fdYLe83DSFk1MYK3

haddock-interfaces:
    /usr/share/doc/haskell-markdown-unlit/html/markdown-unlit.haddock

haddock-html:         /usr/share/doc/haskell-markdown-unlit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
